@@ -10,9 +10,7 @@ import footing.utils
 
 def _get_current_branch():
     """Determine the current git branch"""
-    result = footing.utils.shell(
-        'git rev-parse --abbrev-ref HEAD', stdout=subprocess.PIPE
-    )
+    result = footing.utils.shell('git rev-parse --abbrev-ref HEAD', stdout=subprocess.PIPE)
     return result.stdout.decode('utf8').strip()
 
 
